@@ -1,6 +1,6 @@
 package Elastic::Model::Bulk;
 {
-  $Elastic::Model::Bulk::VERSION = '0.19';
+  $Elastic::Model::Bulk::VERSION = '0.20';
 }
 
 use Moose;
@@ -64,7 +64,7 @@ sub save {
     my $self = shift;
     my $doc  = shift;
 
-    return unless $doc->has_changed || !$doc->uid->from_store;
+    return if $doc->_can_inflate;
 
     my $meta = Class::MOP::class_of($doc);
     die "Cannot bulk index class ("
@@ -215,7 +215,7 @@ Elastic::Model::Bulk - Bulk-saving of multiple docs for increased throughput
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
