@@ -1,6 +1,6 @@
 package Elastic::Model::Role::Model;
 {
-  $Elastic::Model::Role::Model::VERSION = '0.19';
+  $Elastic::Model::Role::Model::VERSION = '0.20';
 }
 
 use Moose::Role;
@@ -15,6 +15,8 @@ use Elastic::Model::UID();
 use Elastic::Model::Deleted();
 use Scalar::Util qw(blessed refaddr weaken);
 use List::MoreUtils qw(uniq);
+use JSON();
+our $JSON = JSON->new->canonical->utf8;
 
 use namespace::autoclean;
 my @wrapped_classes = qw(
@@ -444,18 +446,15 @@ sub _update_unique_keys {
     for my $key ( keys %$uniques ) {
         my $unique_key = $uniques->{$key};
         my $new        = $doc->$key;
+        no warnings 'uninitialized';
 
         if ($from_store) {
-            my $old
-                = $doc->has_changed($key)
-                ? $doc->old_value($key)
-                : $doc->$key;
-            no warnings 'uninitialized';
-            next if $from_store and $old eq $new;
-            $old{$unique_key} = $old if defined $old and length $old;
+            my $old = $doc->_source->{$key};
+            next if $old eq $new;
+            $old{$unique_key} = $old if length $old;
         }
 
-        $new{$unique_key} = $new if defined $new and length $new;
+        $new{$unique_key} = $new if length $new;
     }
 
     my $uniq = $self->es_unique;
@@ -538,11 +537,9 @@ sub _delete_unique_keys {
 
     my %old;
     for my $key ( keys %$uniques ) {
-        my $old
-            = $doc->has_changed($key)
-            ? $doc->old_value($key)
-            : $doc->$key;
-        $old{ $uniques->{$key} } = $old if defined $old and length $old;
+        no warnings 'uninitialized';
+        my $old = $doc->_source->{$key};
+        $old{ $uniques->{$key} } = $old if length $old;
     }
     my $uniq = $self->es_unique;
     return {
@@ -627,6 +624,10 @@ sub map_class {
     return \%mapping;
 }
 
+#===================================
+sub json {$JSON}
+#===================================
+
 1;
 
 
@@ -639,7 +640,7 @@ Elastic::Model::Role::Model - The role applied to your Model
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
